@@ -38,7 +38,7 @@ class Borg(ABC):
     @property
     @abstractmethod
     def _shared_state(self):
-        pass
+        pass  # pragma: no cover
 
 
 class Logger(Borg):
@@ -134,7 +134,7 @@ class ConfigPaths(Borg):
         if self.CUSTOM_PATH:
             if not Path(self.CUSTOM_PATH).is_dir():
                 raise NotADirectoryError(
-                    "Given configuration path {self.CUSTOM_PATH} doesn't exist"
+                    f"Given configuration path {self.CUSTOM_PATH} doesn't exist"
                 )
             configs_path = self.CUSTOM_PATH
 
@@ -187,8 +187,13 @@ class Formats(Enum):
     """Supported output formats."""
 
     csv = "csv"
+    """Simple parameter name, value .csv file."""
     px4 = "px4"
-    px4af = "px4af"
+    """QGroundControl-style parameter file."""
+    px4afv1 = "px4afv1"
+    """Legacy PX4 airframe file, prior to version 1.11."""
+    px4afv2 = "px4afv2"
+    """New PX4 airframe file, version 1.11 and later."""
 
 
 ReservedOptions = Literal[
@@ -212,7 +217,7 @@ class Substances(BaseModel):
     Each is made up by its name, its value and a justification.
     """
 
-    __root__: List[Tuple[str, Optional[Union[int, float]], Optional[str]]]
+    __root__: List[Tuple[str, Optional[Union[float, int]], Optional[str]]]
 
     def __iter__(self):
         """Return an interable of the model."""
@@ -266,6 +271,12 @@ MealsType = Dict[str, MealType]
 DishModel.update_forward_refs()
 
 
+def check_type(key: str, value: Any, des_type: Any) -> None:
+    """Type if value with name key is of type."""
+    if not isinstance(value, des_type):
+        raise TypeError(f"Value of {key}={value} should be {des_type}.")
+
+
 class MealMenuModel(BaseModel):
     """The description of the whole meals catalogue."""
 
@@ -274,19 +285,26 @@ class MealMenuModel(BaseModel):
     @root_validator
     def _check_entries(cls, values):  # noqa: B902
         # Iterate over the meals
-        for meal in values["__root__"].keys():
+        for meal, content in values["__root__"].items():
             # Iterate over the dishes
-            for dish in values["__root__"][meal]:
-                if not (
-                    cls._is_custom_dish(dish)
-                    or cls._is_staple_dish(dish)
-                    or cls._is_reserved_option(dish)
-                ):
-                    raise AssertionError(
-                        f"Meal {meal} contains invalid field/dish {dish}."
-                    )
+            for dish_name in content.keys():
+                cls._check_content_names(dish_name, meal)
+            cls._check_content_values(content)
+
         return values
 
+    @classmethod
+    def _check_content_names(cls, entry_name: str, meal: str) -> None:
+        """Raise an error if the names of the Meal contents are invalid."""
+        if not (
+            cls._is_custom_dish(entry_name)
+            or cls._is_staple_dish(entry_name)
+            or cls._is_reserved_option(entry_name)
+        ):
+            raise AssertionError(
+                f"Meal {meal} contains invalid field/dish {entry_name}."
+            )
+
     @classmethod
     def _is_custom_dish(cls, dish_name: str) -> bool:
         filename = dish_name + ".yaml"
@@ -312,6 +330,28 @@ class MealMenuModel(BaseModel):
         else:
             return False
 
+    @classmethod
+    def _check_content_values(cls, contents: MealType) -> None:
+        """Raise an error if the contents of the Meal are invalid."""
+        # Iterate over the dishes and other entries
+        for key, value in contents.items():
+            if key in StapleDishesNamesSequence:
+                check_type(key, value, (str, type(None)))
+            elif key in ["parent"]:
+                check_type(key, value, str)
+            elif key in [
+                "sitl",
+                "hitl",
+                "remove_calibration",
+                "remove_operator",
+                "add_new",
+            ]:
+                check_type(key, value, bool)
+            elif key in ["frame_id"]:
+                check_type(key, value, int)
+            else:  # This is a custom dish
+                check_type(key, value, (str, type(None)))
+
     def __getitem__(self, item):
         """Access the model in a dict-like manner."""
         return self.__root__[item]
@@ -409,7 +449,7 @@ class Parameter:
 
     name: str
     param_type: Optional[str]  # String, either FLOAT or INT32
-    value: Union[int, float]
+    _value: Union[int, float]
     reasoning = None
     short_desc = None
     long_desc = None
@@ -439,6 +479,19 @@ class Parameter:
         self.vid = vid
         self.cid = cid
 
+    @property
+    def value(self) -> Union[int, float]:
+        """Getter for parameter value."""
+        if self.param_type == "INT32":
+            return int(self._value)
+        else:
+            return self._value
+
+    @value.setter
+    def value(self, new_value: Union[int, float]) -> None:
+        """Setter for parameter value."""
+        self._value = new_value
+
     def __str__(self) -> str:
         """__str__ dunder method."""
         if self.param_type == "FLOAT":
@@ -529,7 +582,7 @@ class ParameterList:
         """Answer if the parameter list contains a parameter."""
         if isinstance(item, str):
             return item in self.params.keys()
-        if isinstance(item, Parameter):
+        else:  # item is Parameter
             return item.name in self.params.keys()
 
     def keys(self) -> KeysView:
@@ -599,7 +652,12 @@ def build_param_from_qgc(row: List[str]) -> Parameter:
     get_logger().debug(f"Decoding parameter file row: {row}")
     vehicle_id = int(row[0])
     componenent_id = int(row[1])
-    param_name = row[2]
+    # Test if parameter name is a number
+    try:
+        float(row[2])
+        raise SyntaxError("Third element must be a parameter name string")
+    except ValueError:
+        param_name = row[2]
     param_type_num = int(row[4])
     if param_type_num == 6:
         param_type = "INT32"
@@ -702,15 +760,12 @@ def read_params_qgc(filepath: Path) -> ParameterList:
             # Test for wrong number of elements
             if len(param_row) != 5:
                 raise SyntaxError("Wrong number of line elements")
-            # Test if 3rd element is a string
-            try:
-                float(param_row[2])
-                raise SyntaxError("First element must be a parameter name string")
-            except ValueError:
-                pass
             param = build_param_from_qgc(param_row)
             param_list.add_param(param)
 
+    if len(param_list.params) == 0:
+        raise (SyntaxError("Could not extract any parameter from file."))
+
     return param_list
 
 
@@ -729,12 +784,15 @@ def read_params_ulog_param(filepath: Path) -> ParameterList:
             # Check if first element is a string
             try:
                 float(param_row[0])
-                raise SyntaxError("First element must be a parameter name string")
+                raise SyntaxError("First row element must be a parameter name string")
             except ValueError:
                 pass
             param = build_param_from_ulog_params(param_row)
             param_list.add_param(param)
 
+    if len(param_list.params) == 0:
+        raise (SyntaxError("Could not extract any parameter from file."))
+
     return param_list
 
 
